//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[options](options.md)

# options

[common]\
val [options](options.md): [HoraOptions](../../mahjongutils.hora/-hora-options/index.md)
